@@ -133,12 +133,9 @@ class EventsRuleToLambda(
         :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
 
-        access:
-        :access:: public
-        since:
-        :since:: 0.8.0
-        summary:
-        :summary:: Constructs a new instance of the EventsRuleToLambda class.
+        :access: public
+        :since: 0.8.0
+        :summary: Constructs a new instance of the EventsRuleToLambda class.
         """
         props = EventsRuleToLambdaProps(
             event_rule_props=event_rule_props,
@@ -181,8 +178,7 @@ class EventsRuleToLambdaProps:
         :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
 
-        summary:
-        :summary:: The properties for the CloudFrontToApiGateway Construct
+        :summary: The properties for the CloudFrontToApiGateway Construct
         """
         if isinstance(event_rule_props, dict):
             event_rule_props = aws_cdk.aws_events.RuleProps(**event_rule_props)
@@ -200,7 +196,6 @@ class EventsRuleToLambdaProps:
     def event_rule_props(self) -> aws_cdk.aws_events.RuleProps:
         """User provided eventRuleProps to override the defaults.
 
-        default
         :default: - None
         """
         result = self._values.get("event_rule_props")
@@ -211,7 +206,6 @@ class EventsRuleToLambdaProps:
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
         """Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
 
-        default
         :default: - None
         """
         result = self._values.get("existing_lambda_obj")
@@ -223,7 +217,6 @@ class EventsRuleToLambdaProps:
     ) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
         """User provided props to override the default props for the Lambda function.
 
-        default
         :default: - Default props are used
         """
         result = self._values.get("lambda_function_props")
